@@ -5,9 +5,10 @@
 """Spelling checker extension for Sphinx.
 """
 
-import codecs
 import collections
+import io
 import os
+import tempfile
 
 import docutils.nodes
 from sphinx.builders import Builder
@@ -15,8 +16,6 @@ from sphinx.util.console import darkgreen, red
 
 from enchant.tokenize import EmailFilter, WikiWordFilter
 
-import six
-
 from . import checker
 from . import filters
 
@@ -61,24 +60,63 @@ class SpellingBuilder(Builder):
             f.append(filters.ImportableModuleFilter)
         f.extend(self.config.spelling_filters)
 
-        project_words = os.path.join(self.srcdir,
-                                     self.config.spelling_word_list_filename)
-        self.info('Looking for custom word list in {}'.format(
-            project_words))
+        if not os.path.isdir(self.outdir):
+            os.mkdir(self.outdir)
+
+        word_list = self.get_wordlist_filename()
+        self.info('Looking for custom word list in {}'.format(word_list))
+
         self.checker = checker.SpellingChecker(
             lang=self.config.spelling_lang,
             tokenizer_lang=self.config.tokenizer_lang,
             suggest=self.config.spelling_show_suggestions,
-            word_list_filename=project_words,
+            word_list_filename=word_list,
             filters=f,
         )
+
         self.output_filename = os.path.join(self.outdir, 'output.txt')
-        if six.PY2:
-            self.output = codecs.open(self.output_filename,
-                                      'w',
-                                      encoding='UTF-8')
-        else:
-            self.output = open(self.output_filename, 'w', encoding='UTF-8')
+        self.output = io.open(self.output_filename, 'w', encoding='UTF-8')
+
+    def get_wordlist_filename(self):
+        word_list = self.config.spelling_word_list_filename
+        if word_list is None:
+            word_list = 'spelling_wordlist.txt'
+
+        if not isinstance(word_list, list):
+            filename = os.path.join(self.srcdir, word_list)
+            return filename
+
+        # In case the user has multiple word lists, we combine them
+        # into one large list that we pass on to the checker.
+        return self._build_combined_wordlist()
+
+    def _build_combined_wordlist(self):
+        # If we have a list, the combined list is the first list plus all words
+        # from the other lists. Otherwise, word_list is assumed to just be a
+        # string.
+        temp_dir = tempfile.mkdtemp()
+        combined_word_list = os.path.join(temp_dir,
+                                          'spelling_wordlist.txt')
+
+        word_list = self.config.spelling_word_list_filename
+
+        with io.open(combined_word_list,
+                     'w',
+                     encoding='UTF-8') as outfile:
+            for word_file in word_list:
+                # Paths are relative
+                long_word_file = os.path.join(self.srcdir, word_file)
+                self.info('Adding contents of {} to custom word list'.format(
+                    long_word_file))
+                with io.open(long_word_file, 'r', encoding='UTF-8') as infile:
+                    infile_contents = infile.readlines()
+                outfile.writelines(infile_contents)
+
+                # Check for newline, and add one if not present
+                if infile and not infile_contents[-1].endswith('\n'):
+                    outfile.write(u'\n')
+
+        return combined_word_list
 
     def get_outdated_docs(self):
         return 'all documents'
@@ -107,9 +145,9 @@ class SpellingBuilder(Builder):
         self.checker.push_filters(self.env.spelling_document_filters[docname])
 
         for node in doctree.traverse(docutils.nodes.Text):
-            if (node.tagname == '#text'
-                    and node.parent
-                    and node.parent.tagname in self.TEXT_NODES):
+            if (node.tagname == '#text' and
+                    node.parent and
+                    node.parent.tagname in self.TEXT_NODES):
 
                 # Figure out the line number for this node by climbing the
                 # tree until we find a node that has a line number.
